@@ -36,8 +36,10 @@ class Client:
             raise Exception(f'{method.upper()} {url} failed -  {result.reason}')
 
         try:
+            if result.text == "" or result.text is None:
+                return None
             return result.json()
-        except Exception as e:
+        except ValueError as e:
             print(result)
             raise Exception(f'Invalid response received from API - {e}')
 
