@@ -13,6 +13,9 @@ class Device:
     def __init__(self, client: Client):
         self._client = client
 
+    def get(self, device_type: str, lookup_key: str, lookup_name: str = 'name'):
+        return self._client.get(route=f'{device_type}/{lookup_name}/{lookup_key}')
+
     def get_many(
             self,
             device_type: str,
@@ -28,6 +31,15 @@ class Device:
             return None
         return res
 
+    def create(self, device_type: str, device_name: str, device_description: str = None):
+        data = {
+            "name": device_name,
+            "type": device_type,
+            "description": device_description
+        }
+        res = self._client.put(route=f'{device_type}', data=data)
+        return res
+
     # def get_schema(self, extension_name) -> FGModel:
     #     data = self._client.get(route=f'{reference_name}')
     #     return FGModel.from_object(reference_name, data.get('links', {}).get('persistenceInfo', []))
